@@ -541,3 +541,19 @@ test_that("glue can use different comment characters (#193)", {
     "foo#"
   )
 })
+
+test_that("`.literal` treats quotes and `#` as regular characters", {
+  expect_snapshot(
+    error = TRUE,
+    glue("{'fo`o\"#}", .transformer = function(x, ...) x)
+  )
+  expect_equal(
+    glue("{'fo`o\"#}", .literal = TRUE, .transformer = function(x, ...) x),
+    "'fo`o\"#"
+  )
+})
+
+test_that("`.literal` is not about (preventing) evaluation", {
+  x <- "world"
+  expect_equal(glue("hello {x}!"), glue("hello {x}!", .literal = TRUE))
+})
